@@ -1,6 +1,8 @@
-Plot.PCA <- function(PC, titles = NA, xlabel = NA, ylabel = NA, size = 1.1,
-                     grid = TRUE, color = TRUE, linlab = NA, savptc = FALSE,
+Plot.PCA <- function(PC, titles = NA, xlabel = NA, ylabel = NA, size = 1.1, 
+                     grid = TRUE, color = TRUE, linlab = NA, axes = TRUE, class = NA, 
+                     classcolor = NA, posleg = 2, boxleg = TRUE, savptc = FALSE,
                      width = 3236, height = 2000, res = 300, casc = TRUE) {
+  
   # Rotina para Plotar Graficos do Metodo PCA desenvolvida 
   # por Paulo Cesar Ossani em 11/2014
   
@@ -13,6 +15,15 @@ Plot.PCA <- function(PC, titles = NA, xlabel = NA, ylabel = NA, size = 1.1,
   # grid   - Coloca grade nos graficos.
   # color  - Graficos coloridos (default = TRUE).
   # linlab - Vetor com os rotulos das observacoes.
+  # axes   - Coloca eixos no grafico (default = TRUE).
+  # class  - Vetor com os nomes das classes dos dados.
+  # classcolor - Vetor com as cores das classes.
+  # posleg  - 0 sem legenda,
+  #           1 para legenda no canto superior esquerdo,
+  #           2 para legenda no canto superior direito (default),
+  #           3 para legenda no canto inferior direito,
+  #           4 para legenda no canto inferior esquerdo. 
+  # boxleg - Colocar moldura na legenda (default = TRUE). 
   # savptc - Salva as imagens dos graficos em arquivos (default = FALSE).
   # width  - Largura do grafico quanto savptc = TRUE (defaul = 3236).
   # height - Altura do grafico quanto savptc = TRUE (default = 2000).
@@ -28,6 +39,14 @@ Plot.PCA <- function(PC, titles = NA, xlabel = NA, ylabel = NA, size = 1.1,
   if (!is.character(titles[2]) || is.na(titles[2])) titles[2] = c("Grafico correspondente as linhas (observacoes)")
   if (!is.character(titles[3]) || is.na(titles[3])) titles[3] = c("Grafico correspondente as colunas (variaveis)")
   
+  if (!is.na(class[1])) {
+    
+     class <- as.matrix(class)
+    
+     if (nrow(PC$mtxscores) != length(class))
+        stop("Entrada 'class' ou 'data' esta incorreta, devem conter o mesmo numero de linhas. Verifique!")
+  }
+  
   if (!is.character(xlabel) && !is.na(xlabel[1]))
      stop("Entrada para 'xlabel' esta incorreta, deve ser do tipo caracter ou string. Verifique!")
   
@@ -43,9 +62,18 @@ Plot.PCA <- function(PC, titles = NA, xlabel = NA, ylabel = NA, size = 1.1,
   if (!is.logical(grid))
      stop("Entrada para 'grid' esta incorreta, deve ser TRUE ou FALSE. Verifique!")
    
-  if (!is.na(linlab[1]) && length(linlab)!=nrow(PC$mtxscores))
+  if (!is.na(linlab[1]) && length(linlab) != nrow(PC$mtxscores))
      stop("O numero elementos do rotulo para linhas 'linlab' difere do numero de linhas da base de dados. Verifique!")
   
+  if (!is.numeric(posleg) || posleg < 0 || posleg > 4 || (floor(posleg)-posleg) != 0)
+     stop("Entrada para posicao da legenda 'posleg' esta incorreta, deve ser um numero inteiro entre [0,4]. Verifique!")
+  
+  if (!is.logical(boxleg)) 
+     stop("Entrada para moldura da legenda 'boxleg' esta incorreta, deve ser TRUE ou FALSE. Verifique!")
+  
+  if (!is.logical(axes)) 
+     stop("Entrada para 'axes' esta incorreta, deve ser TRUE ou FALSE. Verifique!")
+  
   if (!is.logical(savptc))
      stop("Entrada para 'savptc' esta incorreta, deve ser TRUE ou FALSE. Verifique!")
   
@@ -66,6 +94,26 @@ Plot.PCA <- function(PC, titles = NA, xlabel = NA, ylabel = NA, size = 1.1,
   
   if (is.na(ylabel[1]))
      ylabel = paste("Segunda coordenada (",round(PC$mtxAutvlr[2,2],2),"%)",sep="")
+  
+  if (posleg==1) posleg = "topleft"     # posicao das legendas nos graficos
+  if (posleg==2) posleg = "topright"
+  if (posleg==3) posleg = "bottomright"
+  if (posleg==4) posleg = "bottomleft"
+  
+  boxleg = ifelse(boxleg,"o","n") # moldura nas legendas, "n" sem moldura, "o" com moldura
+  
+  num.class = 0
+  if (!is.na(class[1])) {
+     class.Table <- table(class)        # cria tabela com as quantidade dos elementos das classes
+     class.Names <- names(class.Table)  # nomes das classses
+     num.class   <- length(class.Table) # numero de classes
+     NomeLinhas  <- as.matrix(class)
+  } 
+  
+  if (num.class != 0 && length(classcolor) != num.class && !is.na(classcolor) ||
+      num.class == 0 && length(classcolor) != 1 && !is.na(classcolor))
+      stop("Entrada para 'classcolor' esta incorreta, deve ser em quantidade igual ao numero de classes em 'class'. Verifique!")
+  
   #####   FIM - Informacoes usadas nos Graficos  #####
   
   if (savptc) {
@@ -128,28 +176,80 @@ Plot.PCA <- function(PC, titles = NA, xlabel = NA, ylabel = NA, size = 1.1,
        # asp  = 1,  # Aspecto do Grafico
        xlim = c(min(PC$mtxscores[,1])-0.05,max(PC$mtxscores[,1])+0.05), # Dimensao para as linhas do grafico
        ylim = c(min(PC$mtxscores[,2])-0.05,max(PC$mtxscores[,2])+0.05)) # Dimensao para as colunas do grafico
-
+  
   if (grid) {
     
-     args <- append(as.list(par('usr')), c('gray93','gray93'))
+    args <- append(as.list(par('usr')), c('gray93','gray93'))
     
-     names(args) <- c('xleft', 'xright', 'ybottom', 'ytop', 'col', 'border')
+    names(args) <- c('xleft', 'xright', 'ybottom', 'ytop', 'col', 'border')
     
-     do.call(rect, args) # chama a funcao rect com os argumentos (args)
+    do.call(rect, args) # chama a funcao rect com os argumentos (args)
     
-     grid(col = "white", lwd = 2, lty = 7, equilogs = T)
+    grid(col = "white", lwd = 2, lty = 7, equilogs = T)
     
   }
-
-  points(PC$mtxscores, # cria grafico para as coordenadas principais das linhas
-         pch = 15,   # Formato dos pontos 
-         cex = size, # Tamanho dos pontos  
-         col = ifelse(color,"red","black"))  # Cor dos pontos
+  
+  if (num.class == 0) {
     
-  abline(h = 0, v=0, cex = 1.5, lty=2) # cria o eixo central
+      points(PC$mtxscores, # cria grafico para as coordenadas principais das linhas
+             pch = 16,   # Formato dos pontos 
+             cex = size, # Tamanho dos pontos  
+             col = ifelse(color,"red","black"))  # Cor dos pontos
+        
+  } else {
+    
+    if (!is.na(classcolor[1])) {
+       cor.classe <- classcolor
+    }
+    else { cor.classe <- c("red") }
+    
+    newdata <- PC$mtxscores
+    
+    init.form <- 14 # formato inicial dos pontos
+    
+    for (i in 1:num.class) {
+      
+      point.form <- init.form + i # fomato dos pontos de cada classe
+      
+      if (!is.na(classcolor[1])) {
+        cor1 <- ifelse(color, cor.classe[i], "black")
+      }
+      else { cor1 <- ifelse(color, cor + i, "black") }
+      
+      point.data <- newdata[which(class == class.Names[i]),] 
+
+      points(point.data,
+             pch = point.form, # Formato dos pontos
+             cex = size,  # Tamanho dos pontos
+             col = cor1) # adiciona ao grafico as coordenadas principais das colunas
+    }
+    
+    if (posleg != 0 && num.class > 0) {
+      
+      if (color) cor <- 2
+      
+      init.form <- 15
+      
+      cor <- ifelse(color, 2, 1)
+      
+      if (color) {
+        if (!is.na(classcolor[1])) {
+          color_b <- classcolor
+        }
+        else { color_b <- cor:(cor + num.class) }
+      }
+      else { color_b <- cor }
+      
+      legend(posleg, class.Names, pch = (init.form):(init.form + num.class), col = color_b,
+             text.col = color_b, bty = boxleg, text.font = 6, y.intersp = 0.8, xpd = TRUE) # cria a legenda
+    }
+    
+  }
+  
+  if (axes) abline(h = 0, v = 0, cex = 1.5, lty = 2) # cria o eixo central
   
   if (!is.na(linlab[1])) LocLab(PC$mtxscores, cex = 1, linlab)
-  
+
   if (savptc) { box(col = 'white'); dev.off() }
   ##### FIM - Plotagem dos Dados das linhas #####
   
@@ -182,11 +282,11 @@ Plot.PCA <- function(PC, titles = NA, xlabel = NA, ylabel = NA, size = 1.1,
   
   symbols(0, 0, circles = 1, inches = FALSE, fg = 1, add = TRUE) # cria um circulo
   
-  abline(h = 0, v = 0, cex = 1.5, lty = 2) # cria o eixo central
+  if (axes) abline(h = 0, v = 0, cex = 1.5, lty = 2) # cria o eixo central
   
   arrows(0,0,PC$mtxCCP[1,],PC$mtxCCP[2,], lty=1, code = 2, length = 0.08, angle = 25, col = ifelse(color,"Red","Black")) # cria a seta apontando para cada coordenada principal
   
-  LocLab(t(PC$mtxCCP), cex=1, colnames(PC$mtxCCP) , col = ifelse(color,"Blue","Black"), xpd = TRUE)
+  LocLab(t(PC$mtxCCP), cex = 1, colnames(PC$mtxCCP) , col = ifelse(color,"Blue","Black"), xpd = TRUE)
   
   if (savptc) { box(col = 'white'); dev.off() }
   ##### FIM - Plotagem das Correlacoes dos Componentes Principais com as Variaveis Originais #####
